@@ -8,7 +8,6 @@ from classification_model.config.core import config
 from classification_model.preprocessing.data_manager import load_trained
 from classification_model.preprocessing.validation import validate_inputs
 
-
 save_file_name_model = f"{config.app_config.model_save_file}{_version}.h5"
 save_file_name_enc = f"{config.app_config.model_save_file}{_version}.joblib"
 save_file_name_pp = f"{config.app_config.model_save_file}_preprocess{_version}.joblib"
@@ -30,7 +29,9 @@ def make_prediction(
     results = {"predictions": None, "version": _version, "errors": errors}
 
     if not errors:
-        predictions = np.argmax(_model_load.predict(_text_process_pipe.transform(validated_data)), axis=-1)
+        predictions = np.argmax(
+            _model_load.predict(_text_process_pipe.transform(validated_data)), axis=-1
+        )
         results = {
             "predictions": list(_lab_enc.inverse_transform(predictions)),
             "version": _version,
